@@ -35,4 +35,8 @@ def factorial(n):
     if n <= 1:
         return 1
     return n * factorial(n-1)
+
+
+def foo():
+    print("hello world")
     
